==> haskell-integer-conversion-0.1.1-53.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-integer-conversion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 integer-conversion
version:              0.1.1
visibility:           public
id:                   integer-conversion-0.1.1-DRB3SWHoRBCJxKDeuc2gjJ
key:                  integer-conversion-0.1.1-DRB3SWHoRBCJxKDeuc2gjJ
license:              BSD-3-Clause
copyright:            (c) 2023 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/integer-conversion
synopsis:             Conversion from strings to Integer
description:
    The naive @foldl'\'' (\acc d -> acc * 10 + d) 0@ is expensive (quadratic!) for large @Integer@s.
    This package provides sub-quadratic implementation.

category:             Data
abi:                  292026a10eeef2666af2d66187224410
exposed:              True
exposed-modules:      Data.Integer.Conversion
import-dirs:          /usr/lib/ghc-9.6.6/site-local/integer-conversion-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/integer-conversion-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/integer-conversion-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-integer-conversion
hs-libraries:         HSinteger-conversion-0.1.1-DRB3SWHoRBCJxKDeuc2gjJ
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-integer-conversion/html/integer-conversion.haddock

haddock-html:         /usr/share/doc/haskell-integer-conversion/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-integer-conversion-0.1.1-54-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-integer-conversion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 integer-conversion
version:              0.1.1
visibility:           public
id:                   integer-conversion-0.1.1-1JOh3kEXs2A1lWf7CGpMKt
key:                  integer-conversion-0.1.1-1JOh3kEXs2A1lWf7CGpMKt
license:              BSD-3-Clause
copyright:            (c) 2023 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/integer-conversion
synopsis:             Conversion from strings to Integer
description:
    The naive @foldl'\'' (\acc d -> acc * 10 + d) 0@ is expensive (quadratic!) for large @Integer@s.
    This package provides sub-quadratic implementation.

category:             Data
abi:                  92d95d5b5c44f40c11bb6cf10992da26
exposed:              True
exposed-modules:      Data.Integer.Conversion
import-dirs:          /usr/lib/ghc-9.6.6/site-local/integer-conversion-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/integer-conversion-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/integer-conversion-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-integer-conversion
hs-libraries:         HSinteger-conversion-0.1.1-1JOh3kEXs2A1lWf7CGpMKt
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-integer-conversion/html/integer-conversion.haddock

haddock-html:         /usr/share/doc/haskell-integer-conversion/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
